@@ -5,6 +5,7 @@ import re
 import sys
 from collections import defaultdict
 
+import bokeh
 import pandas as pd
 import simplelogging
 from bokeh.models import (
@@ -18,7 +19,9 @@ from nptdms import TdmsFile
 from scipy import integrate
 
 # logging
-log = simplelogging.get_logger()
+os.environ["BOKEH_DEV"] = "false"
+CONSOLE_FORMAT = " %(log_color)s%(message)s%(reset)s"
+log = simplelogging.get_logger(console_format=CONSOLE_FORMAT)
 
 
 # load the tdms file
@@ -51,7 +54,7 @@ def output_directories(path):
         try:
             os.mkdir(out_paths)
         except FileExistsError:
-            log.info(f"Already created {out_paths}")
+            log.debug(f"Already created {out_paths}")
             pass
     return CSV_PATH, PLOT_PATH, RAW_CSV_DATA
 
@@ -69,7 +72,8 @@ def load_data(path):
     ]
     directory_listing = list(
         filter(
-            lambda x: not re.findall(r"(CSV DATA)|(PLOT DATA)|(RAW CSV DATA)", x), directory_listing
+            lambda x: not re.findall(r"(CSV DATA)|(PLOT DATA)|(RAW CSV DATA)", x),
+            directory_listing,
         )
     )
     for directory in directory_listing:
@@ -80,6 +84,7 @@ def load_data(path):
         sample_type == Control
         sample_rep == 3
         """
+        log.info(f"Loading data for -> {directory}")
         sample = re.split(r"[_\-]", directory)[-2]
         sample_type = " ".join(re.split(r"[_\-]", directory)[-1].split(" ")[0:-1])
         sample_rep = " ".join(re.split(r"[_\-]", directory)[-1].split(" ")[-1])
@@ -106,7 +111,9 @@ def load_data(path):
             df = df.sub(initial_condition)
             sample_dict[sample][sample_type][sample_rep] = df
             df.to_csv(
-                os.path.join(RAW_CSV_DATA, f"{sample}_{sample_type}_{sample_rep}.csv"), sep=",", index=True
+                os.path.join(RAW_CSV_DATA, f"{sample}_{sample_type}_{sample_rep}.csv"),
+                sep=",",
+                index=True,
             )
 
         except [FileNotFoundError, OSError] as e:
@@ -122,23 +129,25 @@ def write_and_plot(sample_dict, path):
     integral_data = []
     std_data = {}
     VOLUME = 1.2
-    VOLUME_CALCULATED = (VOLUME / (60 * 1000))
+    VOLUME_CALCULATED = VOLUME / (60 * 1000)
 
     for family in sample_families:
         for method, _ in sample_dict[family].items():
+            log.info(f"Working on {method}")
             composite_data[family][method] = cd = pd.concat(
                 sample_dict[family][method], axis=1
             ).apply(lambda g: pd.Series.interpolate(g, method="cubic"))
-
+            ppm_calculated_once = cd.mul(10000 * 1.9378).droplevel(axis=1, level=1)
             # Integral
-            heating = cd[0:150]
-            ppm = heating.mul(10000*1.9378)
+            ppm = pd.DataFrame(ppm_calculated_once[0:150])
             ppm.reset_index(inplace=True)
-            ppm['Volume'] = ppm['Time'].apply(lambda x: x * VOLUME_CALCULATED)
-            ppm.set_index('Volume', inplace=True)
-            ppm = ppm.drop(columns=['Time'], errors='ignore', level=0)
+            ppm["Volume"] = ppm["Time"].apply(lambda x: x * VOLUME_CALCULATED)
+            ppm.set_index("Volume", inplace=True)
+            ppm = ppm.drop(columns=["Time"], errors="ignore")
             row_integral = (
-                ppm.ewm(span=5).mean().apply(lambda g: integrate.trapz(x=g.index, y=g.values))
+                ppm.ewm(span=5)
+                .mean()
+                .apply(lambda g: integrate.trapz(x=g.index, y=g.values))
             )
             row_integral_std = row_integral.std()
             integral = pd.DataFrame(
@@ -156,28 +165,26 @@ def write_and_plot(sample_dict, path):
                 os.path.join(CSV_PATH, f"{family}_{method}.csv"), sep=",", index=False
             )
 
-            # STD Data
-            cd_mean = cd.mean(axis=1)
-            source_data = cd_mean.reset_index()
-            source_data.columns = ["Time", "CO2"]
-            cd_std = cd.std(axis=1).rolling(window=3).mean().fillna(method="backfill")
-            source_data["lower"] = source_data.CO2 - cd_std.reset_index()[0]
-            source_data["upper"] = source_data.CO2 + cd_std.reset_index()[0]
-            std_data[f"{family} {method} STD"] = cd_std
+            # Mean/STD Data
+            source_data = pd.DataFrame()
+            source_data["mean"] = ppm_calculated_once.mean(axis=1)
+            source_data["std"] = ppm_calculated_once.std(axis=1)
+            source_data["lower"] = source_data["mean"] - source_data["std"]
+            source_data["upper"] = source_data["mean"] + source_data["std"]
 
             # Graphing our data
             output_file(os.path.join(PLOT_PATH, f"{family}-{method}.html"))
+            source_data = source_data.reset_index().rename(columns={"index": "Time"})
             source = ColumnDataSource(source_data)
             p = figure(
                 title=f"{family} {method}",
                 x_axis_label="Time",
                 y_axis_label="CO2 Release",
                 background_fill_color="#efefef",
-                toolbar_location=None
-
+                toolbar_location=None,
             )
             p.line(
-                source=source, x="Time", y="CO2",
+                source=source, x="Time", y="mean",
             )
             band = Band(
                 base="Time",
@@ -194,7 +201,14 @@ def write_and_plot(sample_dict, path):
             p.xgrid[0].grid_line_color = None
             p.ygrid[0].grid_line_alpha = 0.5
             p.xaxis.axis_label = "Time"
-            p.yaxis.axis_label = "CO_2"
+            p.yaxis.axis_label = "CO2 (PPM)"
+            p.y_range.start = source_data["mean"].min() - source_data["std"].max() / 6
+            p.y_range.end = source_data["mean"].max() + source_data["std"].max()
+            p.ygrid.band_fill_alpha = 0.1
+            p.ygrid.band_fill_color = "#C0C0C0"
+            p.add_tools(
+                HoverTool(tooltips=[("Value", "@mean"), ("STD", "@std")], mode="vline")
+            )
 
             show(p)
 
@@ -207,24 +221,36 @@ def write_and_plot(sample_dict, path):
         toolbar_location=None,
         title="CO2 Integral",
         background_fill_color="#efefef",
-        y_axis_label='CO2 (mg)'
+        y_axis_label="CO2 (mg)",
+        tools="tap",
     )
     p.circle(
-        x="index", y="Integral", color="red", fill_alpha=0.2, size=10, source=source
+        x="index",
+        y="Integral",
+        color="red",
+        fill_alpha=0.4,
+        line_color="firebrick",
+        line_alpha=1.0,
+        size=10,
+        source=source,
+        selection_color="firebrick",
+        nonselection_fill_alpha=0.2,
+        nonselection_fill_color="firebrick",
+        nonselection_line_color="blue",
+        nonselection_line_alpha=1.0,
     )
+
     p.add_layout(
         Whisker(
             source=source, base="index", upper="upper", lower="lower", level="overlay"
         )
     )
     p.xaxis.major_label_orientation = "vertical"
-    p.y_range.start = integral_df["Integral"].min() - integral_df["STD"].max() - 5
-    p.y_range.end = integral_df["Integral"].max() + integral_df["STD"].max() + 5
+    p.y_range.start = integral_df["Integral"].min() - integral_df["STD"].max() * 1.2
+    p.y_range.end = integral_df["Integral"].max() + integral_df["STD"].max() * 1.2
     hover = HoverTool()
     hover.tooltips = [("Sample", "@index"), ("Value", "@Integral"), ("STD", "@STD")]
-
     hover.mode = "vline"
-
     p.add_tools(hover)
     show(p)
 
